/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.file.pattern;

import org.junit.Test;
import static org.junit.Assert.*;

public class PatternStepFactoryTest {
    @Test public void testGreedy() {
        PatternStep step = PatternStepFactory.getStep("**", true, true);
        assertTrue(step.isGreedy());
        assertTrue(step.matches("anything", true));
        assertTrue(step.matches("anything", false));
    }

    @Test public void testNormal() {
        PatternStep step = PatternStepFactory.getStep("*.jsp", true, true);
        assertFalse(step.isGreedy());
        assertTrue(step.matches("fred.jsp", true));

        // check case sensitivity param
        assertFalse(step.matches("fred.JSP", true));
        step = PatternStepFactory.getStep("*.jsp", true, false);
        assertTrue(step.matches("fred.JSP", true));
    }
}
