/*
 * Copyright 2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.tasks.bundling

import org.gradle.api.java.archives.internal.DefaultManifest
import org.junit.Before
import org.junit.Test

import static org.junit.Assert.assertEquals
import static org.junit.Assert.assertNotNull

class JarTest extends AbstractArchiveTaskTest {
    Jar jar

    @Before public void setUp()  {
        jar = createTask(Jar)
        configure(jar)
    }

    AbstractArchiveTask getArchiveTask() {
        jar
    }

    @Test public void testJar() {
        assertEquals(Jar.DEFAULT_EXTENSION, jar.extension)
        assertNotNull(jar.manifest)
        assertNotNull(jar.metaInf)
    }

    @Test public void testManifest() {
        jar.manifest = new DefaultManifest(null);
        jar.manifest {
            attributes(key: 'value')
        }
        assertEquals(jar.manifest.attributes.key, 'value')
    }

    @Test public void testManifestWithNullManifest() {
        jar.manifest = null
        jar.manifest {
            attributes(key: 'value')
        }
        assertEquals(jar.manifest.attributes.key, 'value')
    }
}